@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 # Copyright 2014-2020 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 """This is the main module of Lino Noi.
 
 .. autosummary::
@@ -15,6 +15,6 @@ from lino_noi.setup_info import SETUP_INFO
 
 __version__ = SETUP_INFO['version']
 
-srcref_url = 'https://github.com/lino-framework/noi/blob/master/%s'
-intersphinx_urls = dict(docs="http://noi.lino-framework.org")
+srcref_url = 'https://gitlab.com/lino-framework/noi/blob/master/%s'
+intersphinx_urls = dict(docs="https://noi.lino-framework.org")
 doc_trees = ['docs']
