@@ -1,20 +1,21 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2014-2020 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# Copyright 2014-2021 Rumma & Ko Ltd
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 """
 Base Django settings for Lino Noi applications.
 
 """
 
 from lino.projects.std.settings import *
-from lino.api.ad import _
 from lino_noi import SETUP_INFO
+from lino.api import _
 
 class Site(Site):
 
     verbose_name = "Lino Noi"
+    description = SETUP_INFO['description']
     version = SETUP_INFO['version']
-    url = "http://noi.lino-framework.org/"
+    url = SETUP_INFO['url']
 
     demo_fixtures = ['std', 'minimal_ledger', 'demo', 'demo2', 'checksummaries']
                      # 'linotickets',
@@ -25,7 +26,7 @@ class Site(Site):
     textfield_format = 'html'
     user_types_module = 'lino_noi.lib.noi.user_types'
     workflows_module = 'lino_noi.lib.noi.workflows'
-    # custom_layouts_module = 'lino_noi.lib.noi.layouts'
+    custom_layouts_module = 'lino_noi.lib.noi.layouts'
     obj2text_template = "**{0}**"
 
     default_build_method = 'appyodt'
@@ -99,6 +100,8 @@ class Site(Site):
         yield super(Site, self).get_plugin_configs()
         yield ('tickets', 'end_user_model', 'contacts.Person')
         yield ('working', 'ticket_model', 'tickets.Ticket')
+        yield ('system', 'use_dashboard_layouts', True)
+        # yield ('users', 'use_verify', True)
 
 
     # def setup_plugins(self):
@@ -119,30 +122,21 @@ class Site(Site):
         # `auth=True`. In Lino Noi everybody can see everything.
         return kw
 
-    def setup_quicklinks(self, user, tb):
-        super(Site, self).setup_quicklinks(user, tb)
-        # tb.add_action(self.models.courses.MyActivities)
-        # tb.add_action(self.models.meetings.MyMeetings)
-        # tb.add_action(self.modules.deploy.MyMilestones)
-        # tb.add_action(self.models.tickets.MyTickets)
-        # tb.add_action(self.models.tickets.TicketsToTriage)
-        # tb.add_action(self.models.tickets.TicketsToTalk)
-        # tb.add_action(self.modules.tickets.TicketsToDo)
-        tb.add_action(self.models.tickets.RefTickets)
-        tb.add_action(self.models.tickets.ActiveTickets)
-        tb.add_action(self.models.tickets.AllTickets)
-        tb.add_action(
-            self.models.tickets.AllTickets.insert_action,
-            label=_("Submit a ticket"))
-
-        a = self.models.users.MySettings.default_action
-        tb.add_instance_action(
-            user, action=a, label=_("My settings"))
-        # handler = self.action_call(None, a, dict(record_id=user.pk))
-        # handler = "function(){%s}" % handler
-        # mysettings = dict(text=_("My settings"),
-        #                   handler=js_code(handler))
-
+    # def setup_quicklinks(self, user, tb):
+    #     super(Site, self).setup_quicklinks(user, tb)
+    #     # tb.add_action(self.models.courses.MyActivities)
+    #     # tb.add_action(self.models.meetings.MyMeetings)
+    #     # tb.add_action(self.modules.deploy.MyMilestones)
+    #     # tb.add_action(self.models.tickets.MyTickets)
+    #     # tb.add_action(self.models.tickets.TicketsToTriage)
+    #     # tb.add_action(self.models.tickets.TicketsToTalk)
+    #     # tb.add_action(self.modules.tickets.TicketsToDo)
+    #     tb.add_action(self.models.tickets.RefTickets)
+    #     tb.add_action(self.models.tickets.ActiveTickets)
+    #     tb.add_action(self.models.tickets.AllTickets)
+    #     tb.add_action(
+    #         self.models.tickets.AllTickets.insert_action,
+    #         label=_("Submit a ticket"))
 
     def do_site_startup(self):
         super(Site, self).do_site_startup()
