@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 # Copyright 2016-2020 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """Database models specific for Lino Noi.
 
@@ -78,13 +78,13 @@ class Ticket(Ticket, Assignable, Summarized):
     #     """Add a star"""
     #     self.add_change_watcher(self.user)
 
-    def after_ui_create(self, ar):
-        # print("Create")
-        # self.site_changed(ar)
-        # self.assigned_to_changed(ar)
-        # self.end_user_changed(ar)
-        # self.user_changed(ar)
-        super(Ticket, self).after_ui_create(ar)
+    # def after_ui_create(self, ar):
+    #     # print("Create")
+    #     # self.site_changed(ar)
+    #     # self.assigned_to_changed(ar)
+    #     # self.end_user_changed(ar)
+    #     # self.user_changed(ar)
+    #     super(Ticket, self).after_ui_create(ar)
 
     show_commits = dd.ShowSlaveTable('github.CommitsByTicket')
     show_changes = dd.ShowSlaveTable('changes.ChangesByMaster')
